@@ -10,10 +10,12 @@ use Carp qw/carp/;
 
 =head1 NAME
 
-Test::Exception::LessClever - Test::Exception simplified
+Test::Exception::LessClever - Test::Exception simplified ***DEPRECATED***
 
 =head1 DESCRIPTION
 
+*** This is deprecated please do not use it ***
+
 An alternative to L<Test::Exception> that is much simpler. This alternative
 does not use fancy stack tricks to hide itself. The idea here is to keep it
 simple. This also solves the Test::Exception bug where some dies will be hidden
@@ -57,7 +59,7 @@ our @EXPORT_OK = qw/live_or_die/;
 our @EXPORT = qw/lives_ok dies_ok throws_ok lives_and/;
 our @CARP_NOT = ( __PACKAGE__ );
 our $TB = Test::Builder->new;
-our $VERSION = "0.005";
+our $VERSION = "0.007";
 
 =item $status = live_or_die( sub { ... }, $name )
 
@@ -154,7 +156,7 @@ sub throws_ok(&$;$) {
 =item lives_and( sub {...}, $name )
 
 Fails with $name if the sub dies, otherwise is passive. This is useful for
-running a test that could die. If it dies there is a failure, fi ti lives it is
+running a test that could die. If it dies there is a failure, if it lives it is
 responsible for itself.
 
 =cut
